package migration

//go:generate go-bindata -pkg migration -prefix scripts scripts

import (
	"github.com/golang-migrate/migrate/v4"
	"github.com/golang-migrate/migrate/v4/database/postgres"
	"github.com/golang-migrate/migrate/v4/source"
	"github.com/golang-migrate/migrate/v4/source/go_bindata"
	"github.com/orus-io/yago"
)

// New returns a migrate instance for migrating the given database
func New(db *yago.DB) (*migrate.Migrate, source.Driver, error) {
	// wrap assets into Resource
	s := bindata.Resource(
		AssetNames(),
		func(name string) ([]byte, error) {
			return Asset(name)
		})

	source, err := bindata.WithInstance(s)
	if err != nil {
		return nil, nil, err
	}
	database, err := postgres.WithInstance(db.Engine.DB().DB, &postgres.Config{})
	if err != nil {
		return nil, nil, err
	}
	m, err := migrate.NewWithInstance(
		"go-bindata", source,
		"postgres", database,
	)
	return m, source, err
}
